ApiResponse class

Constructors

ApiResponse(int statusCode, Map<String, List<String>> headers, Stream<List<int>>? body)

Properties

body ↔ Stream<List<int>>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, List<String>>
getter/setter pair
innerException ↔ Exception?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ StackTrace?
getter/setter pair
statusCode ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited