DeserialisationError class

represents a failed deserialisation in nullSafe mode because we cannot find a non-null version of the field

Implemented types

Constructors

DeserialisationError(Map<String, dynamic> data, String fieldName, String className, String reason)

Properties

className ↔ String
getter/setter pair
data ↔ Map<String, dynamic>
getter/setter pair
fieldName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reason ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited