HttpBasicAuth class

Implemented types

Constructors

HttpBasicAuth()

Properties

hashCode → int
The hash code for this object.
no setterinherited
password ← String
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ← String
no getter

Methods

applyToParams(List<QueryParam> queryParams, Map<String, dynamic> headerParams) → void
Apply authentication settings to header and query params.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited